<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bn">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>অ্যাপ্লিকেশন প্রক্সি</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>প্রক্সি প্রকার</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>আইপি ঠিকানা</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>আবশ্যক</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>পোর্ট</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ব্যবহারকারীর নাম </translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>ঐচ্ছিক</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>পাসওয়ার্ড</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>কনফিগার করার পরে লঞ্চারের অ্যাপ্লিকেশন কন্টেক্সট মেনুতে &quot;একটি প্রক্সি ব্যবহার করুন&quot; টিক দিন</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>বাতিল করুন</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>সংরক্ষণ করুন</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid port</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>সংযোগ বিচ্ছিন্ন করুন</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>মুছে ফেলুন</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>বাতিল করুন</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>সংরক্ষণ করুন</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>সংযুক্ত হচ্ছে</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>সংযোগ বিচ্ছিন্ন করুন</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>%1 তারের সংযোগ</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>হটস্পট</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>%1 PPPoE সংযোগ</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>নতুন VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>পিপিটিপি</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>স্ট্রংসওয়ান</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>রপ্তানি</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>%1 ভিপিএন L2TP</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>%1 ভিপিএন PPTP</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>%1 ভিপিএন ভিপিএনসি</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>%1 ভিপিএন ওপেন ভিপিএন</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>%1 ভিপিএন স্ট্রংসওয়ান</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>%1 ভিপিএন ওপেন কানেক্ট</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>নেটওয়ার্ক</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>অ্যাপ্লিকেশন প্রক্সি</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network Details</source>
        <translation>নেটওয়ার্কের বিবরণ</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>সিস্টেমের প্রক্সি</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>ওয়্যার্ড নেটওয়ার্ক</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>ওয়্যারলেস নেটওয়ার্ক</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-child_page>Airplane Mode</extra-child_page>
        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation type="unfinished"/>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation type="unfinished"/>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation type="unfinished"/>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>গোপন নেটওয়ার্কে সংযুক্ত করুন</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
    </message>
    <message>
        <source>DSL</source>
        <translation>ডিএসএল</translation>
        <extra-child_page_hide>DSL</extra-child_page_hide>
        <extra-contents_path>/network/DSL</extra-contents_path>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>PPPoE সংযোগ তৈরি করুন</translation>
        <extra-child_page>DSL</extra-child_page>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>VPN এর অবস্থা</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN</extra-contents_path>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>VPN তৈরি করুন</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>VPN আমদানি করুন</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>প্রক্সি প্রকার</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>কনফিগারেশন URL</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>আইপি ঠিকানা</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Port</source>
        <translation>পোর্ট</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Username</source>
        <translation>ব্যবহারকারীর নাম </translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Password</source>
        <translation>পাসওয়ার্ড</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>হটস্পট</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation type="unfinished"/>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Interface</source>
        <translation>ইন্টারফেস</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>MAC</source>
        <translation>ম্যাক</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Band</source>
        <translation>দল</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Gateway</source>
        <translation>প্রবেশপথ</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>প্রাথমিক DNS</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Netmask</source>
        <translation>নেটমাস্ক</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Prefix</source>
        <translation>উপসর্গ</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Speed</source>
        <translation>গতি</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>ইথারনেট</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>আবাদ্ধ নয়</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>ডিভাইস ম্যাক Addr</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>ক্লোন ম্যাক Addr</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>MTU কে কাস্টমাইজ করুন</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU </translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>সাধারণ</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Required</source>
        <translation>আবশ্যক</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>সাধারণ</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Name</source>
        <translation>নাম </translation>
    </message>
    <message>
        <source>Required</source>
        <translation>আবশ্যক</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>হটস্পট</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>সেটিংস যোগ করুন</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>আইপি ঠিকানা</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>আবশ্যক</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>প্রবেশপথ</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Netmask</source>
        <translation>নেটমাস্ক</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>আবশ্যক</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Prefix</source>
        <translation>উপসর্গ</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>অটো</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>ম্যানুয়াল</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>উপেক্ষা করা</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>আইপি ঠিকানা</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>আবশ্যক</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>প্রবেশপথ</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>শুধুমাত্র সংশ্লিষ্ট সম্পদ প্রয়োগ</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>পদ্ধতি</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>নেটমাস্ক</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>উপসর্গ</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network</source>
        <translation>নেটওয়ার্ক</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>পদ্ধতি</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>অটো</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>ম্যানুয়াল</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>উপেক্ষা করা</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>নেটওয়ার্কের বিবরণ</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>ডিএসএল</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>সিস্টেমের প্রক্সি</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>অ্যাপ্লিকেশন প্রক্সি</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>নেটওয়ার্কের বিবরণ</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>নেটওয়ার্ক</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disabled</source>
        <translation>অক্ষম</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>ম্যানুয়াল</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>অটো</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ব্যবহারকারীর নাম </translation>
    </message>
    <message>
        <source>Required</source>
        <translation>আবশ্যক</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>সেবা</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>পাসওয়ার্ড</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>পিপিপি</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>ইএপি প্রমাণীকরণ প্রত্যাখ্যান করুন</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>পিএপি প্রমাণীকরণ প্রত্যাখ্যান করুন</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP প্রমাণীকরণ প্রত্যাখ্যান করুন</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP প্রমাণীকরণ প্রত্যাখ্যান করুন</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2 প্রমাণীকরণ প্রত্যাখ্যান করুন</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>কোন BSD ডাটা কম্প্রেশন</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>কোন ডেফ্লেট ডেটা কম্প্রেশন</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>কোন টিসিপি হেডার কম্প্রেশন</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>কোন প্রোটোকল ক্ষেত্র সংকোচন</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>কোন ঠিকানা / কন্ট্রোল কম্প্রেশন</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>পিপিপি ইকো প্যাকেটগুলি পাঠান</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>এমপিপিই ব্যবহার করুন</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-বিট এমপিপিই</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>PPPoE সংযোগ তৈরি করুন</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>পিপিপি</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>সিস্টেমের প্রক্সি</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>বাতিল করুন</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>সংরক্ষণ করুন</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>প্রক্সি প্রকার</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
    <message>
        <source>Manual</source>
        <translation>ম্যানুয়াল</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>অটো</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>ঐচ্ছিক</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>পোর্ট</translation>
    </message>
    <message>
        <source>Authentication is required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP প্রক্সি</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS প্রক্সি</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP প্রক্সি</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS প্রক্সি</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>উপরের হোস্ট এবং ডোমেনগুলির জন্য প্রক্সি কনফিগারেশন উপেক্ষা করুন</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>কনফিগারেশন URL</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>নিরাপত্তা</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>টিএলএস</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>লিপ</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>দ্রুত</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>টানেলড টিএলএস</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>সুরক্ষিত EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ask me always</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disabled</source>
        <translation>অক্ষম</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>নামবিহীন</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>প্রমাণীকৃত</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>উভয়</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>স্বয়ংক্রিয়</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>সংস্করণ 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>সংস্করণ 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP Auth</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>পরিচয়</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>আবশ্যক</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd অপশনগুলো</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>ব্যক্তিগত কী</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA সনদ</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>ব্যবহারকারীর সনদ</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>নামহীন আইডি</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>প্রভিশনিং</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>পিএসি ফাইল</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>ইনার Auth</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP সংস্করণ</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>ব্যক্তিগত Pwd</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>পাসওয়ার্ড</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation>কোনটিই নয়</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA / WPA2 ব্যক্তিগত</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>নিরাপত্তা</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>আবশ্যক</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>চাবি</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>পাসওয়ার্ড</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>নিরাপত্তা প্রয়োজন</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation>কোনটিই নয়</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA / WPA2 ব্যক্তিগত</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA / WPA2 এন্টারপ্রাইজ</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared key</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>নিরাপত্তা</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>আবশ্যক</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Key</source>
        <translation>চাবি</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>পাসওয়ার্ড</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>ভিপিএন অ্যাডভান্সড</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>গেটওয়ে পোর্ট কাস্টমাইজ করুন</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>গেটওয়ে পোর্ট</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>পুনর্বিবেচনা বিরতি কাস্টমাইজ করুন</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>রেনগোটেশান বিরতি</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>LZO ডেটা কম্প্রেশন ব্যবহার করুন </translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>TCP সংযোগ ব্যবহার করুন</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>TAP ডিভাইস ব্যবহার করুন</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>এমটি টানেল কাস্টমাইজ করুন</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU </translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>UDP ফ্র্যাগমেন্ট সাইজ কাস্টমাইজ করুন</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP ফ্র্যাগমেন্ট সাইজ</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>টানেল টিসিপি এমএসএস নিয়ন্ত্রণ করুন</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>র্যান্ডমাইজ রিমোট হোস্ট</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>ভিপিএন অ্যাডভান্সড</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>সিসকো (ডিফল্ট)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>নিরাপদ (ডিফল্ট)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>দুর্বল</translation>
    </message>
    <message>
        <source>None</source>
        <translation>কোনটিই নয়</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T উপলভ্য হলে (ডিফল্ট)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T সর্বদা</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>সিসকো ইউডিপি</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>অক্ষম</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH গ্রুপ 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH গ্রুপ 2 (ডিফল্ট)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH গ্রুপ 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>সার্ভার (ডিফল্ট)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH গ্রুপ 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>ডোমেইন</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>বিক্রেতা</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>সংস্করণ</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>এনক্রিপশন</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NAT ট্রাভেরসাল  মোড</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH গ্রুপ</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>ফরওয়ার্ড গোপনীয়তা</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>স্থানীয় পোর্ট</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>মৃত পীর সনাক্তকরণ অক্ষম করুন</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>ভিপিএন IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>IPsec সক্ষম করুন</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>দলের নাম</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>দলের আইডি</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>প্রাক-ভাগ করা কী</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>পর্ব 1 এর অ্যালগরিদম সমূহ</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>পর্ব 2 এর অ্যালগরিদম সমূহ</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gateway</source>
        <translation>প্রবেশপথ</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>আবশ্যক</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA সনদ</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>প্রক্সি</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>সিসকো সিকিউর ডেস্কটপ Trojan অনুমতি দিন</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>সিএসডি স্ক্রিপ্ট</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>ব্যবহারকারীর সনদ</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>ব্যক্তিগত কী</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>কী পাসফ্রেজের জন্য FSID ব্যবহার করুন</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>সার্টিফিকেট (টিএলএস)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>পাসওয়ার্ড</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>পাসওয়ার্ড (TLS) সহ সার্টিফিকেট</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>স্ট্যাটিক কী</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>সংরক্ষিত</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>জিজ্ঞেস করুন</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>আবশ্যক না</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>প্রবেশপথ</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>আবশ্যক</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>AUTH প্রকার</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA সনদ</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>ব্যবহারকারীর সনদ</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>ব্যক্তিগত কী</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd অপশনগুলো</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>ব্যক্তিগত Pwd</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ব্যবহারকারীর নাম </translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>কী দিকনির্দেশনা কাস্টমাইজ করুন</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>কী দিকনির্দেশনা</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>দূরবর্তী আইপি</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>স্থানীয় আইপি</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>ভিপিএন পিপিপি</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>সব উপলব্ধ (ডিফল্ট)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-বিট (কম নিরাপদ)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-বিট (সবচেয়ে নিরাপদ)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>ইএপি প্রমাণীকরণ প্রত্যাখ্যান করুন</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>পিএপি প্রমাণীকরণ প্রত্যাখ্যান করুন</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP প্রমাণীকরণ প্রত্যাখ্যান করুন</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP প্রমাণীকরণ প্রত্যাখ্যান করুন</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2 প্রমাণীকরণ প্রত্যাখ্যান করুন</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>কোন BSD ডাটা কম্প্রেশন</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>কোন ডেফ্লেট ডেটা কম্প্রেশন</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>কোন টিসিপি হেডার কম্প্রেশন</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>কোন প্রোটোকল ক্ষেত্র সংকোচন</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>কোন ঠিকানা / কন্ট্রোল কম্প্রেশন</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>পিপিপি ইকো প্যাকেটগুলি পাঠান</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>এমপিপিই ব্যবহার করুন</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>নিরাপত্তা</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>VPN এর অবস্থা</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>VPN তৈরি করুন</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>VPN আমদানি করুন</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>আমদানি করার সময় ত্রুটি</translation>
    </message>
    <message>
        <source>File error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation>ঠিক আছে</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>ভিপিএন প্রক্সি</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>আবশ্যক না</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>সক্স</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>প্রক্সি প্রকার</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>সার্ভার আইপি</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>আবশ্যক</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>পোর্ট</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>ব্যর্থ হলে অনির্দিষ্টকালের জন্য পুনরায় চেষ্টা করুন </translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ব্যবহারকারীর নাম </translation>
    </message>
    <message>
        <source>Password</source>
        <translation>পাসওয়ার্ড</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>CA ফাইল</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>সার্টিফিকেট সতর্কতাগুলো উপেক্ষা করুন</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>TLS Hostname Extension সমূহ ব্যবহার করুন</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>ভিপিএন সিকিউরিটি</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>পূর্বনির্ধারিত</translation>
    </message>
    <message>
        <source>None</source>
        <translation>কোনটিই নয়</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>গোল্লা</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC Auth</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saved</source>
        <translation>সংরক্ষিত</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>জিজ্ঞেস করুন</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>আবশ্যক না</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>প্রবেশপথ</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>আবশ্যক</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ব্যবহারকারীর নাম </translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd অপশনগুলো</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>পাসওয়ার্ড</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>এনটি ডোমেন</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>ভিপিএন প্রক্সি</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>সার্ভার আইপি</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>পোর্ট</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ব্যবহারকারীর নাম </translation>
    </message>
    <message>
        <source>Password</source>
        <translation>পাসওয়ার্ড</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Private Key</source>
        <translation>ব্যক্তিগত কী</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>এসএসএইচ এজেন্ট</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EAP</source>
        <translation>ইএপি</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>প্রাক-ভাগ করা কী</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>প্রবেশপথ</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>আবশ্যক</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA সনদ</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>AUTH প্রকার</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>ব্যবহারকারীর সনদ</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ব্যবহারকারীর নাম </translation>
    </message>
    <message>
        <source>Password</source>
        <translation>পাসওয়ার্ড</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>একটি ইনার আইপি ঠিকানা অনুরোধ করুন</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>UDP Encapsulation প্রয়োগ করুন</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>আইপি কম্প্রেশন ব্যবহার করুন</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>কাস্টম  সংকেতের প্রস্তাব সক্রিয় করুন</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>ভিপিএন TLS প্রমাণীকরণ</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>পূর্বনির্ধারিত</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>খরিদ্দার</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>সার্ভার</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>বিষয় ম্যাচ</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>রিমোট সার্ট টাইপ</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>কী ফাইল</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>কী দিকনির্দেশনা কাস্টমাইজ করুন</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>কী দিকনির্দেশনা</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saved</source>
        <translation>সংরক্ষিত</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>জিজ্ঞেস করুন</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>আবশ্যক না</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>প্রবেশপথ</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>আবশ্যক</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ব্যবহারকারীর নাম </translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd অপশনগুলো</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>পাসওয়ার্ড</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>দলের নাম</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>গ্রুপ Pwd</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>হাইব্রীড প্রমাণীকরণ ব্যবহার করুন</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CA ফাইল</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>আগে নেটওয়ার্ক ক্যাবলটি লাগান</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>সেটিংস নির্বাচন করুন</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>হটস্পট বন্ধ করুন</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>গোপন নেটওয়ার্কে সংযুক্ত করুন</translation>
        <extra-child_page>WirelessPage</extra-child_page>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>আবাদ্ধ নয়</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>ডিভাইস ম্যাক Addr</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>MTU কে কাস্টমাইজ করুন</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU </translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>হটস্পট</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security Type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Channel</source>
        <translation>চ্যানেল</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>দল</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>ইন্টারফেস</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>ম্যাক</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>নেটমাস্ক</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>প্রবেশপথ</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>প্রাথমিক DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>উপসর্গ</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>গতি</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>ডিভাইস নিষ্ক্রিয়</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>সংযুক্ত কিন্তু কোনো ইন্টারনেট এক্সেস নেই</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>সংযুক্ত নয়</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>নেটওয়ার্ক তার তোলা হয়েছে</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>সংযুক্ত হচ্ছে</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>প্রমাণীকরণ হচ্ছে</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>আইপি ঠিকানা নেওয়া হচ্ছে</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>সংযুক্ত</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>অসংযুক্ত</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>ব্যর্থ হয়েছে</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>ওয়্যার্ড নেটওয়ার্ক</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>ওয়্যারলেস নেটওয়ার্ক</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>ওয়্যারলেস নেটওয়ার্ক %1</translation>
    </message>
</context>
</TS>